@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding:utf-8; mode:python -*-
 #
-# Copyright 2020, 2021 Pradyumna Paranjape
+# Copyright 2020-2022 Pradyumna Paranjape
 # This file is part of psprint.
 #
 # psprint is free software: you can redistribute it and/or modify
@@ -17,27 +17,25 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with psprint.  If not, see <https://www.gnu.org/licenses/>.
 #
-'''
-Prompt String-like Print
-'''
+"""Prompt String-like Print"""
 
 import os
 import sys
 
-from .config import read_config
-from .printer import PrintSpace
+from psprint.config import read_config
+from psprint.printer import PrintSpace
 
 
 # Initiate default print function
 def init_print(custom: os.PathLike = None) -> PrintSpace:
-    '''
+    """
     Initiate ps-print function with default marks
     and marks read from various psprintrc configurarion files
 
     Args:
         custom: custom configuration file location
 
-    '''
+    """
 
     default_print = read_config(custom)
 
@@ -49,24 +47,20 @@ def init_print(custom: os.PathLike = None) -> PrintSpace:
 
 
 DEFAULT_PRINT = init_print()
-'''
+"""
 PrintSpace object created by reading defaults from various
 psprintrc and psprint/style.yml files
-
-'''
+"""
 
 print = DEFAULT_PRINT.psprint
-'''
-psprint function for imports
-
-'''
+"""psprint function for imports"""
 
 psfmt = DEFAULT_PRINT.psfmt
-'''
-ps formatting function for imports
-
-'''
+"""ps formatting function for imports"""
 
 __all__ = ['DEFAULT_PRINT', 'print']
 
-__version__ = '1!1.3.0'
+__author__ = 'Pradyumna Paranjape'
+__copyright_years__ = '2020-2022'
+
+__version__ = '1!1.3.2'
