@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding:utf-8; mode:python -*-
 #
-# Copyright 2020 Pradyumna Paranjape
+# Copyright 2020-2022 Pradyumna Paranjape
 # This file is part of psprint.
 #
 # psprint is free software: you can redistribute it and/or modify
@@ -17,18 +17,16 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with psprint.  If not, see <https://www.gnu.org/licenses/>.
 #
-'''
-ANSI colors' and styles' definitions
-'''
+"""ANSI colors' and styles' definitions"""
 
 import types
 from pathlib import Path
 
 import yaml
 
-with open(Path(__file__).resolve().parent.joinpath("ansi.yml"), "r") as stream:
+with open(Path(__file__).resolve().parent / 'ansi.yml', 'r') as stream:
     ANSI = types.SimpleNamespace(**yaml.safe_load(stream))
-    '''
+    """
     ANSI codes' namespace
 
     Earlier, these values were imported from
@@ -56,4 +54,4 @@ with open(Path(__file__).resolve().parent.joinpath("ansi.yml"), "r") as stream:
       * 2: dim
       * 3: bright
 
-    '''
+    """
