@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding:utf-8; mode:python -*-
 #
-# Copyright 2020 Pradyumna Paranjape
+# Copyright 2020-2022 Pradyumna Paranjape
 # This file is part of psprint.
 #
 # psprint is free software: you can redistribute it and/or modify
@@ -16,33 +16,23 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with psprint.  If not, see <https://www.gnu.org/licenses/>.
 #
-'''
-Information Marker
-
-'''
+"""Information Marker"""
 
 import warnings
 from typing import Dict, Union
 
-from .ansi import ANSI
-from .errors import ValueWarning
-from .text_types import AnsiEffect, PrintPref
+from psprint.ansi import ANSI
+from psprint.errors import ValueWarning
+from psprint.text_types import AnsiEffect, PrintPref
 
 DEFAULT_STYLE: Dict[str, int] = {'color': 16, 'gloss': 1, 'bgcol': 16}
-'''
-Terminal-determined color, black background, normal gloss
-
-'''
+"""Terminal-determined color, black background, normal gloss"""
 
 
 class InfoMark():
-    '''
+    """
     Prefix Mark information
 
-    Attributes:
-        pref: PrintPref: Prefix text properties
-        text: PrintText: Text properties
-
     Args:
         parent: Inherit information from-
         pref_max: pad prefix to reach length
@@ -63,7 +53,7 @@ class InfoMark():
                 * text_gloss: gloss of text
                 * text_bgcol: background color of text
 
-    '''
+    """
     def __init__(self,
                  parent: 'InfoMark' = None,
                  pref_max: int = None,
@@ -107,12 +97,12 @@ class InfoMark():
                               pref=pref,
                               pref_max=pref_max,
                               **pref_args)
+        """Prefix text properties"""
         self.text = AnsiEffect(parent=parent_text, **text_args)
+        """Text properties"""
 
     def __repr__(self) -> str:
-        '''
-        String format of available information
-        '''
+        """String format of available information"""
         return "\t".join(
             (str(self.pref.style), self.pref.pref[0], self.pref.pref[1],
              self.text.style + "<CUSTOM>" + ANSI.RESET_ALL))
@@ -125,10 +115,7 @@ class InfoMark():
         return True
 
     def get_info(self) -> str:  # pragma: no cover
-        '''
-        Print information about ``InfoMark``
-
-        '''
+        """Print information about ``InfoMark``"""
         info = str(self)
         print(info)
         return info
