@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding:utf-8; mode:python -*-
 #
-# Copyright 2020 Pradyumna Paranjape
+# Copyright 2020-2022 Pradyumna Paranjape
 # This file is part of psprint.
 #
 # psprint is free software: you can redistribute it and/or modify
@@ -17,9 +17,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with psprint.  If not, see <https://www.gnu.org/licenses/>.
 #
-'''
-Information- Prepended Print object
-'''
+"""Information- Prepended Print object"""
 
 from collections.abc import Iterable
 from sys import stderr, stdout
@@ -27,9 +25,9 @@ from types import GeneratorType
 from typing import Any, Dict, Generator, List, Optional, Tuple, Union
 from warnings import warn
 
-from .ansi import ANSI
-from .errors import BadMark, DeepIterWarning, LongIterWarning
-from .mark_types import InfoMark
+from psprint.ansi import ANSI
+from psprint.errors import BadMark, DeepIterWarning, LongIterWarning
+from psprint.mark_types import InfoMark
 
 
 class PrintSpace():
@@ -40,37 +38,36 @@ class PrintSpace():
         conf: parsed configuration
         name: name of configuration file (to report errors)
 
-    Attributes:
-        pref_max: int: maximum length of prefix string
-        info_style; dict: pre-configured prefix styles
-        info_index: list: keys of `info_style` mapped to int
-        print_kwargs: dict : library of kwargs_accepted by print_function
-        switches: dict: user-customizations: pad, short, bland, disabled
-
-            pad: bool: prefix is padded to start text at the same level
-            short: bool: display short, 1 character- prefix
-            bland: bool: do not show ANSI color/styles for prefix/text
-            disabled: bool: behave like python default print_function
 
     """
     def __init__(self, conf: Dict[str, dict] = None, name: str = None) -> None:
         # Standard info styles
-        self.switches = {
+        self.switches: Dict[str, bool] = {
             'pad': False,
             'short': False,
             'bland': False,
             'iterate': False,
             'disabled': False
         }
+        """User-customizations:
+            * pad: Prefix is padded to start text at the same level
+            * short: display short, 1 character- prefix
+            * bland: do not show ANSI color/styles for prefix/text
+            * disabled: behave like python default print_function
+        """
         self.print_kwargs = {
             'file': stdout,
             'sep': "\t",
             'end': "\n",
             'flush': False
         }
+        """Library of kwargs_accepted by print_function"""
         self.pref_max = None
+        """Maximum length of prefix string"""
         self.info_style: Dict[str, InfoMark] = {}
+        """Pre-configured prefix styles"""
         self.info_index: List[str] = []
+        """Keys of `info_style` mapped to int"""
         if conf is not None:
             self.set_opts(conf, name or 'unnamed config file')
 
@@ -146,7 +143,7 @@ class PrintSpace():
         for mark, settings in conf.items():
             if mark == "FLAGS":
                 # switches / flags
-                self.pref_max = settings.get("pref_max", None)
+                self.pref_max = settings.get("pref_max", self.pref_max)
 
                 # update psprint switches
                 self.switches.update(
@@ -156,8 +153,9 @@ class PrintSpace():
 
                 # update __builtin__,print kwargs
                 self.print_kwargs.update(
-                    dict(filter(lambda x: x[0] in self.print_kwargs,
-                                settings)))
+                    dict(
+                        filter(lambda x: x[0] in self.print_kwargs,
+                               settings.items())))
 
                 # standard output file
                 fname = settings.get("file", None)  # Discouraged
@@ -352,7 +350,15 @@ class PrintSpace():
                              file=stderr)
                 warn('...long stack...', category=LongIterWarning)
                 return
-            if isinstance(value, Iterable) and not isinstance(value, str):
+            if any(hasattr(value, io) for io in ('read', 'write')):
+                # IO stream
+                value = value.name if hasattr(value, 'name') else repr(value)
+                self.psprint(f'{key}: {value}',
+                             mark='list',
+                             **kwargs,
+                             file=stderr)
+            elif isinstance(value,
+                            Iterable) and not isinstance(value, (str, bytes)):
                 self.psprint(f'{key}:', mark='list', end='', **kwargs)
                 self.psprint(value, **kwargs)
             else:
