@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding:utf-8; mode:python -*-
 #
-# Copyright 2020 Pradyumna Paranjape
+# Copyright 2020-2022 Pradyumna Paranjape
 # This file is part of psprint.
 #
 # psprint is free software: you can redistribute it and/or modify
@@ -17,19 +17,17 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with psprint.  If not, see <https://www.gnu.org/licenses/>.
 #
-'''
-Text Parts
-
-'''
+"""Text Parts"""
 
 from typing import List, Tuple, Union
 
-from .ansi import ANSI
-from .errors import BadBGCol, BadColor, BadGloss, BadPrefix, BadShortPrefix
+from psprint.ansi import ANSI
+from psprint.errors import (BadBGCol, BadColor, BadGloss, BadPrefix,
+                            BadShortPrefix)
 
 
 class AnsiEffect():
-    '''
+    """
     Plain text object
     Text to be printed to (ANSI) terminal
 
@@ -38,17 +36,12 @@ class AnsiEffect():
         gloss: gloss of text {0: bland, 1:normal ,2: dim, 3: bright}
         bgcol: color of background [0-15]
 
-    Attributes:
-        color: color of text
-        gloss: gloss of text
-        bgcol: background color
-
     Raises:
         BadColor
         BadGloss
         BadBGCol
 
-    '''
+    """
     def __init__(self,
                  parent=None,
                  color: str = None,
@@ -60,14 +53,17 @@ class AnsiEffect():
         # modify
         try:
             self.color: str = ANSI.FG_COLORS[color] if color else self.color
+            """color of text"""
         except KeyError:
             raise BadColor(color) from None
         try:
             self.gloss: str = ANSI.GLOSS[gloss] if gloss else self.gloss
+            """gloss of text"""
         except KeyError:
             raise BadGloss(gloss) from None
         try:
             self.bgcol: str = ANSI.BG_COLORS[bgcol] if bgcol else self.bgcol
+            """background color"""
         except KeyError:
             raise BadBGCol(bgcol) from None
 
@@ -79,37 +75,31 @@ class AnsiEffect():
         return True
 
     def __str__(self) -> str:
-        '''
-        Human readable form
-        '''
+        """Human readable form"""
         return self.style
 
     def __repr__(self) -> str:  # pragma: no cover
-        '''
-        repr(self)
-        '''
+        """repr(self)"""
         return ' '.join((repr(self.color), repr(self.gloss), repr(self.bgcol)))
 
     @staticmethod
     def inherit(parent):
-        '''
+        """
         object without parent
         set attributes to defaults
-        '''
+        """
         if parent is None:
             return ANSI.FG_COLORS['t'], ANSI.GLOSS['n'], ANSI.BG_COLORS['t']
         return parent.color, parent.gloss, parent.bgcol
 
     @property
     def style(self) -> str:
-        '''
-        All style combined
-        '''
+        """All style combined"""
         return self.color + self.bgcol + self.gloss
 
 
 class PrintPref():
-    '''
+    """
     Prefix that informs about Text
 
     Args:
@@ -128,26 +118,23 @@ class PrintPref():
                 * gloss: gloss of prefix
                 * bgcol: background color of prefix
 
-
-    Arguments:
-        pref: tuple: prefix long, short
-        brackets: tuple: bool long, short
-        pad: tuple: pad long, short
-        style: AnsiEffect: color/gloss style
-
     Raises:
         BadPrefix
         BadShortPrefix
 
-    '''
+    """
     def __init__(self,
                  parent=None,
                  pref: List[str] = None,
                  pref_max: int = 0,
                  **kwargs) -> None:
+        self.pref: List[str] = []
+        """prefix long, short"""
         self.brackets = [1, 1]
+        """bool long, short"""
         style, self.pref = self._inherit(parent=parent, pref=pref)
         self.style = AnsiEffect(parent=style, **kwargs)
+        """color/gloss style"""
         # 0: long, 1: short
         pad_max = (pref_max, 1)
         pad_len: List[int] = [0, 0]
@@ -160,6 +147,7 @@ class PrintPref():
                 pad_len[idx] += 2  # corresponding to `[]`
             pad_len[idx] += max(pad_max[idx] - len(pref_type), 0)
         self.pad = [' ' * (span + 1) for span in pad_len]
+        """pad (long, short)"""
 
     def __eq__(self, other) -> bool:
         if any(
@@ -169,18 +157,15 @@ class PrintPref():
         return True
 
     def __len__(self) -> int:  # pragma: no cover
-        '''
-        length of prefix
-        '''
+        """length of prefix"""
         return len(self.pref[0])
 
     @staticmethod
     def _inherit(
             parent=None,
-            pref: List[str] = None) -> Tuple[Union[AnsiEffect, None], list]:
-        '''
-        inherit pref and style from parent if not supplied
-        '''
+            pref: List[str] = None
+    ) -> Tuple[Union[AnsiEffect, None], List[str]]:
+        """inherit pref and style from parent if not supplied"""
         if parent is None:
             return None, pref or ['', '']
         if pref is None:  # pragma: no cover
@@ -191,14 +176,14 @@ class PrintPref():
         return parent.style, pref
 
     def to_str(self, **kwargs) -> str:
-        '''
+        """
         Print prefix with style
 
         Args:
             short: prefix in short form?
             pad: Pad prefix
             bland: colorless pref
-        '''
+        """
         pref_typ = int(kwargs.get('short', False))  # 1 if short, else 0
         parts = {
             'ansi': '' if kwargs.get('bland') else str(self.style),
