@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding:utf-8; mode:python -*-
 #
-# Copyright 2020, 2021 Pradyumna Paranjape
+# Copyright 2020-2022 Pradyumna Paranjape
 # This file is part of psprint.
 #
 # psprint is free software: you can redistribute it and/or modify
@@ -17,6 +17,4 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with psprint.  If not, see <https://www.gnu.org/licenses/>.
 #
-'''
-tests
-'''
+"""tests"""
