@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding:utf-8; mode:python -*-
 #
-# Copyright 2020, 2021 Pradyumna Paranjape
+# Copyright 2020-2022 Pradyumna Paranjape
 # This file is part of psprint.
 #
 # psprint is free software: you can redistribute it and/or modify
@@ -17,9 +17,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with psprint.  If not, see <https://www.gnu.org/licenses/>.
 #
-"""
-Test configurations
-"""
+"""Test configurations"""
 import os
 import tempfile
 import unittest
@@ -27,7 +25,7 @@ from pathlib import Path
 
 import toml
 import yaml
-from psprint import errors, init_print
+from psprint import init_print
 from xdgpspconf.errors import BadConf
 
 CONFIG_YML = '\n'.join([
@@ -50,18 +48,14 @@ CONFIG_YML = '\n'.join([
 
 class TestPrintSpace(unittest.TestCase):
     def test_yml(self):
-        '''
-        yml configuration marks
-        '''
+        """yml configuration marks"""
         with tempfile.NamedTemporaryFile('wt', delete=False) as config:
             config.write(CONFIG_YML)
         test_print = init_print(Path(config.name))
         self.assertIn('test', test_print)
 
     def test_toml(self):
-        '''
-        yml configuration marks
-        '''
+        """yml configuration marks"""
         with tempfile.NamedTemporaryFile('wt', delete=False) as config:
             config_toml = toml.dumps(yaml.safe_load(CONFIG_YML))
             print(config_toml)
@@ -70,9 +64,7 @@ class TestPrintSpace(unittest.TestCase):
         self.assertIn('test', test_print)
 
     def test_bad_mark(self):
-        '''
-        bad mark defined
-        '''
+        """bad mark defined"""
         with tempfile.NamedTemporaryFile('wt', delete=False) as config:
             bad_yml = CONFIG_YML.replace('test:', 'test: []')
             config.write(bad_yml)
