@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding:utf-8; mode:python -*-
 #
-# Copyright 2020, 2021 Pradyumna Paranjape
+# Copyright 2020-2022 Pradyumna Paranjape
 # This file is part of psprint.
 #
 # psprint is free software: you can redistribute it and/or modify
@@ -17,9 +17,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with psprint.  If not, see <https://www.gnu.org/licenses/>.
 #
-'''
-test print
-'''
+"""test print"""
 
 import tempfile
 import unittest
@@ -31,9 +29,7 @@ from psprint.printer import PrintSpace
 
 
 class TestPrintSpace(unittest.TestCase):
-    """
-    Test basic functions
-    """
+    """Test basic functions"""
     def setUp(self):
         self.test_print = init_print()
 
@@ -46,51 +42,35 @@ class TestPrintSpace(unittest.TestCase):
         self.assertNotEqual(self.test_print, mod_print)
 
     def test_defaults_load(self):
-        """
-        print all default marks
-        """
+        """print all default marks"""
         print(self.test_print)
 
     def test_eq_compare_marks(self):
-        """
-        compare InfoMarks
-        """
+        """compare InfoMarks"""
         self.assertEqual(self.test_print[0], self.test_print[0])
 
     def test_eq_compare_ansi(self):
-        """
-        compare text of marks
-        """
+        """compare text of marks"""
         self.assertEqual(self.test_print[0].text, self.test_print[0].text)
 
     def test_ne_compare_marks(self):
-        """
-        compare InfoMarks
-        """
+        """compare InfoMarks"""
         self.assertNotEqual(self.test_print[0], self.test_print[1])
 
     def test_ne_compare_ansi(self):
-        """
-        compare text of marks
-        """
+        """compare text of marks"""
         self.assertNotEqual(self.test_print[6].text, self.test_print[1].text)
 
     def test_disabled(self):
-        """
-        Disable fancy
-        """
+        """Disable fancy"""
         self.test_print.psprint('Disabled', disabled=True)
 
     def test_default_mark(self):
-        """
-        Default print
-        """
+        """Default print"""
         self.test_print.psprint("Info Mark", mark='info')
 
     def test_new_mark(self):
-        """
-        Test kwarg
-        """
+        """Test kwarg"""
         configuration = '\n'.join([
             'FLAGS:',
             '  short: No',
@@ -125,9 +105,7 @@ class TestPrintSpace(unittest.TestCase):
         self.assertIn('info', self.test_print)
 
     def test_on_the_fly(self):
-        """
-        Test definition on the fly
-        """
+        """Test definition on the fly"""
         self.test_print.psprint("OTF text",
                                 pref="OTF",
                                 pref_s="o",
@@ -136,9 +114,7 @@ class TestPrintSpace(unittest.TestCase):
                                 short=True)
 
     def test_mod_mark(self):
-        """
-        Test a modified mark
-        """
+        """Test a modified mark"""
         self.test_print.psprint("MOD MARK test",
                                 mark=2,
                                 pref_color="lg",
@@ -146,35 +122,25 @@ class TestPrintSpace(unittest.TestCase):
                                 pref_s=None)
 
     def test_edit(self):
-        """
-        test edit style
-        """
+        """test edit style"""
         self.test_print.edit_style(pref="my_test", index_int=4)
 
     def test_int_pref(self):
-        """
-        int/float as prefix
-        """
+        """int/float as prefix"""
         self.test_print.psprint("bad prefix", pref=1234)
 
     def test_pop_style(self):
-        """
-        test edit style
-        """
+        """test edit style"""
         self.test_print.remove_style(4)
 
     def test_remove_style_mark(self):
-        """
-        test removal by passing InfoMark object
-        """
+        """test removal by passing InfoMark object"""
         rem_mark = self.test_print[0]
         print(rem_mark)
         self.test_print.remove_style(rem_mark)
 
     def test_allow_unknown_mark(self):
-        """
-        allow an unknown mark (interpret as 0/cont)
-        """
+        """allow an unknown mark (interpret as 0/cont)"""
         self.test_print.psprint("Test Unknown", mark=88)
 
     def test_precreated_mark(self):
@@ -188,9 +154,7 @@ class TestPrintSpace(unittest.TestCase):
 
 class TextErrors(unittest.TestCase):
     def test_warns(self):
-        """
-        Check that warnings are thrown
-        """
+        """Check that warnings are thrown"""
         self.assertWarns(errors.PSPrintWarning,
                          DEFAULT_PRINT.psprint,
                          "warn_text",
@@ -199,18 +163,14 @@ class TextErrors(unittest.TestCase):
                          pref_s="LONG SHORT")
 
     def test_bad_pref(self):
-        """
-        trigger a bad prefix
-        """
+        """trigger a bad prefix"""
         self.assertRaises((errors.BadPrefix, errors.BadShortPrefix),
                           DEFAULT_PRINT.psprint,
                           "bad prefix",
                           pref=["bad list prefix"])
 
     def test_bad_col(self):
-        """
-        trigger a bad color error
-        """
+        """trigger a bad color error"""
         self.assertRaises(errors.BadColor,
                           DEFAULT_PRINT.psprint,
                           "bad color",
@@ -225,24 +185,18 @@ class TextErrors(unittest.TestCase):
                           pref_gloss=77)
 
     def test_bad_rm_mark(self):
-        """
-        test mark removal error
-        """
+        """test mark removal error"""
         self.assertRaises(KeyError, DEFAULT_PRINT.remove_style, None)
 
     def test_bad_mark(self):
-        """
-        test bad mark creation
-        """
+        """test bad mark creation"""
         self.assertRaises(errors.BadMark,
                           DEFAULT_PRINT.psprint,
                           "bad mark",
                           mark=[])
 
     def test_nokey(self):
-        """
-        bad key not in PrintSpace
-        """
+        """bad key not in PrintSpace"""
         self.assertRaises(KeyError, DEFAULT_PRINT.__getitem__, list())
 
 
@@ -282,3 +236,10 @@ class TestIter(unittest.TestCase):
             }
         }, {1, 2, 3, 4}]),
                               mark="info")
+
+    @staticmethod
+    def test_iter_io():
+        with tempfile.NamedTemporaryFile('r') as iostream:
+            DEFAULT_PRINT.psprint({'test_file': iostream},
+                                  iterate=True,
+                                  mark="info")
